@@ -8,13 +8,13 @@ using xs::lib::sv2string;
 using panda::uri::Query;
 using panda::lib::string_hash;
 
-XSURI::UriClassMap XSURI::uri_class_map;
+XSURIWrapper::UriClassMap XSURIWrapper::uri_class_map;
 
-void XSURI::register_perl_scheme (pTHX_ const char* scheme, const char* perl_class) {
+void XSURIWrapper::register_perl_scheme (pTHX_ const char* scheme, const char* perl_class) {
     uri_class_map[string_hash(scheme)] = newSVpvn_share(perl_class, strlen(perl_class), 0);
 }
 
-SV* XSURI::get_perl_class (pTHX_ const URI* uri) {
+SV* XSURIWrapper::get_perl_class (pTHX_ const URI* uri) {
     static SV* default_perl_class = newSVpvs_share("Panda::URI");
     UriClassMap::iterator it = uri_class_map.find(string_hash(uri->scheme().data(), uri->scheme().length()));
     if (it == uri_class_map.end()) return default_perl_class;
@@ -48,7 +48,7 @@ static void hv2query (pTHX_ HV* hvquery, Query* query) {
     });
 }
 
-void XSURI::add_query_args (pTHX_ URI* uri, SV** sp, I32 items, bool replace) {
+void XSURIWrapper::add_query_args (pTHX_ URI* uri, SV** sp, I32 items, bool replace) {
     if (items == 1) {
         if (SvROK(*sp)) {
             SV* var = SvRV(*sp);
@@ -63,7 +63,7 @@ void XSURI::add_query_args (pTHX_ URI* uri, SV** sp, I32 items, bool replace) {
     }
 }
 
-void XSURI::add_param (pTHX_ URI* uri, string key, SV* val, bool replace) {
+void XSURIWrapper::add_param (pTHX_ URI* uri, string key, SV* val, bool replace) {
     if (SvROK(val) && SvTYPE(SvRV(val)) == SVt_PVAV) {
         if (replace) uri->query().erase(key);
         XS_AV_ITER_NE((AV*)SvRV(val), {
@@ -74,7 +74,7 @@ void XSURI::add_param (pTHX_ URI* uri, string key, SV* val, bool replace) {
     else uri->query().insert(key, sv2string(aTHX_ val));
 }
 
-void XSURI::add_query_hv (pTHX_ URI* uri, HV* hash, bool replace) {
+void XSURIWrapper::add_query_hv (pTHX_ URI* uri, HV* hash, bool replace) {
     if (replace) {
         Query query;
         hv2query(aTHX_ (HV*)hash, &query);
@@ -85,7 +85,7 @@ void XSURI::add_query_hv (pTHX_ URI* uri, HV* hash, bool replace) {
     });
 }
 
-void XSURI::sync_query_hv (pTHX) const {
+void XSURIWrapper::sync_query_hv (pTHX) const {
     HV* hash;
     if (query_cache) {
         hash = (HV*) SvRV(query_cache);
